pub struct BlockchainChainAnchorConfig {
pub chain_id: u32,
pub chain_name: String,
pub checkpoint_height: u64,
pub checkpoint_hash: String,
pub checkpoint_timestamp: u64,
pub max_head_skew_blocks: u64,
pub max_head_age_secs: u64,
pub max_future_drift_secs: u64,
}Expand description
Locally trusted finalized chain checkpoint and freshness policy.
Fields
chain_id: u32Chain ID obtained independently from the configured providers.
chain_name: StringChain name obtained independently from the configured providers.
checkpoint_height: u64Finalized checkpoint height.
checkpoint_hash: StringFinalized checkpoint hash as a 32-byte hexadecimal string.
checkpoint_timestamp: u64Finalized checkpoint timestamp in Unix seconds.
max_head_skew_blocks: u64Maximum permitted height difference among provider heads.
max_head_age_secs: u64Maximum permitted age of a decision head in seconds.
max_future_drift_secs: u64Maximum permitted future drift of a decision head in seconds.
Implementations
Sourceimpl BlockchainChainAnchorConfig
impl BlockchainChainAnchorConfig
Sourcepub fn builder() -> BlockchainChainAnchorConfigBuilder
pub fn builder() -> BlockchainChainAnchorConfigBuilder
Create an instance of BlockchainChainAnchorConfig using the builder syntax