pub struct BlockchainChainAnchorConfigBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> BlockchainChainAnchorConfigBuilder<S>
impl<S: State> BlockchainChainAnchorConfigBuilder<S>
Sourcepub fn build(self) -> BlockchainChainAnchorConfigwhere
S: IsComplete,
pub fn build(self) -> BlockchainChainAnchorConfigwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn chain_id(
self,
value: u32,
) -> BlockchainChainAnchorConfigBuilder<SetChainId<S>>where
S::ChainId: IsUnset,
pub fn chain_id(
self,
value: u32,
) -> BlockchainChainAnchorConfigBuilder<SetChainId<S>>where
S::ChainId: IsUnset,
Required.
Chain ID obtained independently from the configured providers.
Sourcepub fn chain_name(
self,
value: String,
) -> BlockchainChainAnchorConfigBuilder<SetChainName<S>>where
S::ChainName: IsUnset,
pub fn chain_name(
self,
value: String,
) -> BlockchainChainAnchorConfigBuilder<SetChainName<S>>where
S::ChainName: IsUnset,
Required.
Chain name obtained independently from the configured providers.
Sourcepub fn checkpoint_height(
self,
value: u64,
) -> BlockchainChainAnchorConfigBuilder<SetCheckpointHeight<S>>where
S::CheckpointHeight: IsUnset,
pub fn checkpoint_height(
self,
value: u64,
) -> BlockchainChainAnchorConfigBuilder<SetCheckpointHeight<S>>where
S::CheckpointHeight: IsUnset,
Required.
Finalized checkpoint height.
Sourcepub fn checkpoint_hash(
self,
value: String,
) -> BlockchainChainAnchorConfigBuilder<SetCheckpointHash<S>>where
S::CheckpointHash: IsUnset,
pub fn checkpoint_hash(
self,
value: String,
) -> BlockchainChainAnchorConfigBuilder<SetCheckpointHash<S>>where
S::CheckpointHash: IsUnset,
Required.
Finalized checkpoint hash as a 32-byte hexadecimal string.
Sourcepub fn checkpoint_timestamp(
self,
value: u64,
) -> BlockchainChainAnchorConfigBuilder<SetCheckpointTimestamp<S>>where
S::CheckpointTimestamp: IsUnset,
pub fn checkpoint_timestamp(
self,
value: u64,
) -> BlockchainChainAnchorConfigBuilder<SetCheckpointTimestamp<S>>where
S::CheckpointTimestamp: IsUnset,
Required.
Finalized checkpoint timestamp in Unix seconds.
Sourcepub fn max_head_skew_blocks(
self,
value: u64,
) -> BlockchainChainAnchorConfigBuilder<SetMaxHeadSkewBlocks<S>>where
S::MaxHeadSkewBlocks: IsUnset,
pub fn max_head_skew_blocks(
self,
value: u64,
) -> BlockchainChainAnchorConfigBuilder<SetMaxHeadSkewBlocks<S>>where
S::MaxHeadSkewBlocks: IsUnset,
Required.
Maximum permitted height difference among provider heads.
Sourcepub fn max_head_age_secs(
self,
value: u64,
) -> BlockchainChainAnchorConfigBuilder<SetMaxHeadAgeSecs<S>>where
S::MaxHeadAgeSecs: IsUnset,
pub fn max_head_age_secs(
self,
value: u64,
) -> BlockchainChainAnchorConfigBuilder<SetMaxHeadAgeSecs<S>>where
S::MaxHeadAgeSecs: IsUnset,
Required.
Maximum permitted age of a decision head in seconds.
Sourcepub fn max_future_drift_secs(
self,
value: u64,
) -> BlockchainChainAnchorConfigBuilder<SetMaxFutureDriftSecs<S>>where
S::MaxFutureDriftSecs: IsUnset,
pub fn max_future_drift_secs(
self,
value: u64,
) -> BlockchainChainAnchorConfigBuilder<SetMaxFutureDriftSecs<S>>where
S::MaxFutureDriftSecs: IsUnset,
Required.
Maximum permitted future drift of a decision head in seconds.