pub struct BlockchainDataClientConfig {
pub chain: SharedChain,
pub dex_ids: Vec<DexType>,
pub use_hypersync_for_live_data: bool,
pub http_rpc_url: String,
pub rpc_requests_per_second: Option<u32>,
pub multicall_calls_per_rpc_request: u32,
pub wss_rpc_url: Option<String>,
pub proxy_url: Option<String>,
pub from_block: Option<u64>,
pub pool_filters: DexPoolFilters,
pub postgres_cache_database_config: Option<PostgresConnectOptions>,
pub transport_backend: TransportBackend,
}Expand description
Configuration for blockchain data clients.
Fields
chain: SharedChainThe blockchain chain configuration.
dex_ids: Vec<DexType>List of decentralized exchange IDs to register and sync during connection.
use_hypersync_for_live_data: boolDetermines if the client should use Hypersync for live data streaming.
http_rpc_url: StringThe HTTP URL for the blockchain RPC endpoint.
rpc_requests_per_second: Option<u32>The maximum number of RPC requests allowed per second.
multicall_calls_per_rpc_request: u32The maximum number of Multicall calls per one RPC request.
wss_rpc_url: Option<String>The WebSocket secure URL for the blockchain RPC endpoint.
proxy_url: Option<String>Optional proxy URL for HTTP and WebSocket transports.
from_block: Option<u64>The block from which to sync historical data.
pool_filters: DexPoolFiltersFiltering criteria that define which DEX pools to include in the data universe.
postgres_cache_database_config: Option<PostgresConnectOptions>Optional configuration for data client’s Postgres cache database
transport_backend: TransportBackendWebSocket transport backend (defaults to Tungstenite).
Implementations
Sourceimpl BlockchainDataClientConfig
impl BlockchainDataClientConfig
Sourcepub fn builder() -> BlockchainDataClientConfigBuilder
pub fn builder() -> BlockchainDataClientConfigBuilder
Create an instance of BlockchainDataClientConfig using the builder syntax