BlockchainDataClientConfigBuilder

Struct BlockchainDataClientConfigBuilder 

pub struct BlockchainDataClientConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> BlockchainDataClientConfigBuilder<S>

pub fn build(self) -> BlockchainDataClientConfig
where S: IsComplete,

Finish building and return the requested object

pub fn chain( self, value: SharedChain, ) -> BlockchainDataClientConfigBuilder<SetChain<S>>
where S::Chain: IsUnset,

Required.

The blockchain chain configuration.

pub fn dex_ids( self, value: Vec<DexType>, ) -> BlockchainDataClientConfigBuilder<SetDexIds<S>>
where S::DexIds: IsUnset,

Optional (Some / Option setters). Default: <Vec<DexType> as Default>::default().

List of decentralized exchange IDs to register and sync during connection.

pub fn maybe_dex_ids( self, value: Option<Vec<DexType>>, ) -> BlockchainDataClientConfigBuilder<SetDexIds<S>>
where S::DexIds: IsUnset,

Optional (Some / Option setters). Default: <Vec<DexType> as Default>::default().

List of decentralized exchange IDs to register and sync during connection.

pub fn use_hypersync_for_live_data( self, value: bool, ) -> BlockchainDataClientConfigBuilder<SetUseHypersyncForLiveData<S>>
where S::UseHypersyncForLiveData: IsUnset,

Optional (Some / Option setters). Default: false.

Determines if the client should use Hypersync for live data streaming.

pub fn maybe_use_hypersync_for_live_data( self, value: Option<bool>, ) -> BlockchainDataClientConfigBuilder<SetUseHypersyncForLiveData<S>>
where S::UseHypersyncForLiveData: IsUnset,

Optional (Some / Option setters). Default: false.

Determines if the client should use Hypersync for live data streaming.

pub fn http_rpc_url( self, value: String, ) -> BlockchainDataClientConfigBuilder<SetHttpRpcUrl<S>>
where S::HttpRpcUrl: IsUnset,

Required.

The HTTP URL for the blockchain RPC endpoint.

pub fn rpc_requests_per_second( self, value: u32, ) -> BlockchainDataClientConfigBuilder<SetRpcRequestsPerSecond<S>>
where S::RpcRequestsPerSecond: IsUnset,

Optional (Some / Option setters). The maximum number of RPC requests allowed per second.

pub fn maybe_rpc_requests_per_second( self, value: Option<u32>, ) -> BlockchainDataClientConfigBuilder<SetRpcRequestsPerSecond<S>>
where S::RpcRequestsPerSecond: IsUnset,

Optional (Some / Option setters). The maximum number of RPC requests allowed per second.

pub fn multicall_calls_per_rpc_request( self, value: u32, ) -> BlockchainDataClientConfigBuilder<SetMulticallCallsPerRpcRequest<S>>
where S::MulticallCallsPerRpcRequest: IsUnset,

Optional (Some / Option setters). Default: 200.

The maximum number of Multicall calls per one RPC request.

pub fn maybe_multicall_calls_per_rpc_request( self, value: Option<u32>, ) -> BlockchainDataClientConfigBuilder<SetMulticallCallsPerRpcRequest<S>>
where S::MulticallCallsPerRpcRequest: IsUnset,

Optional (Some / Option setters). Default: 200.

The maximum number of Multicall calls per one RPC request.

pub fn wss_rpc_url( self, value: String, ) -> BlockchainDataClientConfigBuilder<SetWssRpcUrl<S>>
where S::WssRpcUrl: IsUnset,

Optional (Some / Option setters). The WebSocket secure URL for the blockchain RPC endpoint.

pub fn maybe_wss_rpc_url( self, value: Option<String>, ) -> BlockchainDataClientConfigBuilder<SetWssRpcUrl<S>>
where S::WssRpcUrl: IsUnset,

Optional (Some / Option setters). The WebSocket secure URL for the blockchain RPC endpoint.

pub fn proxy_url( self, value: String, ) -> BlockchainDataClientConfigBuilder<SetProxyUrl<S>>
where S::ProxyUrl: IsUnset,

Optional (Some / Option setters). Optional proxy URL for HTTP and WebSocket transports.

pub fn maybe_proxy_url( self, value: Option<String>, ) -> BlockchainDataClientConfigBuilder<SetProxyUrl<S>>
where S::ProxyUrl: IsUnset,

Optional (Some / Option setters). Optional proxy URL for HTTP and WebSocket transports.

pub fn from_block( self, value: u64, ) -> BlockchainDataClientConfigBuilder<SetFromBlock<S>>
where S::FromBlock: IsUnset,

Optional (Some / Option setters). The block from which to sync historical data.

pub fn maybe_from_block( self, value: Option<u64>, ) -> BlockchainDataClientConfigBuilder<SetFromBlock<S>>
where S::FromBlock: IsUnset,

Optional (Some / Option setters). The block from which to sync historical data.

pub fn pool_filters( self, value: DexPoolFilters, ) -> BlockchainDataClientConfigBuilder<SetPoolFilters<S>>
where S::PoolFilters: IsUnset,

Optional (Some / Option setters). Default: <DexPoolFilters as Default>::default().

Filtering criteria that define which DEX pools to include in the data universe.

pub fn maybe_pool_filters( self, value: Option<DexPoolFilters>, ) -> BlockchainDataClientConfigBuilder<SetPoolFilters<S>>
where S::PoolFilters: IsUnset,

Optional (Some / Option setters). Default: <DexPoolFilters as Default>::default().

Filtering criteria that define which DEX pools to include in the data universe.

pub fn postgres_cache_database_config( self, value: PostgresConnectOptions, ) -> BlockchainDataClientConfigBuilder<SetPostgresCacheDatabaseConfig<S>>
where S::PostgresCacheDatabaseConfig: IsUnset,

Optional (Some / Option setters). Optional configuration for data client’s Postgres cache database

pub fn maybe_postgres_cache_database_config( self, value: Option<PostgresConnectOptions>, ) -> BlockchainDataClientConfigBuilder<SetPostgresCacheDatabaseConfig<S>>
where S::PostgresCacheDatabaseConfig: IsUnset,

Optional (Some / Option setters). Optional configuration for data client’s Postgres cache database

pub fn transport_backend( self, value: TransportBackend, ) -> BlockchainDataClientConfigBuilder<SetTransportBackend<S>>
where S::TransportBackend: IsUnset,

Optional (Some / Option setters). Default: <TransportBackend as Default>::default().

WebSocket transport backend (defaults to Tungstenite).

pub fn maybe_transport_backend( self, value: Option<TransportBackend>, ) -> BlockchainDataClientConfigBuilder<SetTransportBackend<S>>
where S::TransportBackend: IsUnset,

Optional (Some / Option setters). Default: <TransportBackend as Default>::default().

WebSocket transport backend (defaults to Tungstenite).