pub struct BlockchainProviderIdentityBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> BlockchainProviderIdentityBuilder<S>
impl<S: State> BlockchainProviderIdentityBuilder<S>
Sourcepub fn build(self) -> BlockchainProviderIdentitywhere
S: IsComplete,
pub fn build(self) -> BlockchainProviderIdentitywhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn provider_id(
self,
value: String,
) -> BlockchainProviderIdentityBuilder<SetProviderId<S>>where
S::ProviderId: IsUnset,
pub fn provider_id(
self,
value: String,
) -> BlockchainProviderIdentityBuilder<SetProviderId<S>>where
S::ProviderId: IsUnset,
Required.
Stable local provider identifier.
Sourcepub fn operator_id(
self,
value: String,
) -> BlockchainProviderIdentityBuilder<SetOperatorId<S>>where
S::OperatorId: IsUnset,
pub fn operator_id(
self,
value: String,
) -> BlockchainProviderIdentityBuilder<SetOperatorId<S>>where
S::OperatorId: IsUnset,
Required.
Stable local operator identifier.
Sourcepub fn failure_domain_ids(
self,
value: Vec<String>,
) -> BlockchainProviderIdentityBuilder<SetFailureDomainIds<S>>where
S::FailureDomainIds: IsUnset,
pub fn failure_domain_ids(
self,
value: Vec<String>,
) -> BlockchainProviderIdentityBuilder<SetFailureDomainIds<S>>where
S::FailureDomainIds: IsUnset,
Required.
Opaque identifiers for every known shared infrastructure failure domain.